*
* Replication for Blanchard and Quah(1989), "The Dynamic Effects of Aggregate
* Demand and Supply Disturbances", AER, vol 79, no. 4, pp 655-673.
*
* This includes the figures and tables that require simulations. Note that BQ used
* bootstrapping, which did not work well in this case. This is a point made in
* Sims and Zha(1999), "Error Bands for Impulse Responses", Econometrica, vol 67,
* no. 5, pp 1113-1156. These are done by Monte Carlo integration with the standard
* "Jeffrey's" prior.
*
cal(q) 1948
open data bqdata.xls
data(format=xls,org=cols) 1948:1 1987:4 gnp gd87 lhmur
*
* Generate log real GNP from the gnp and the price deflator
*
set loggnp   = log(gnp)
set loggd    = log(gd87)
set logrgnp  = loggnp-loggd+log(100)
set dlogrgnp = 100.0*(logrgnp-logrgnp{1})
*
* BQ de-mean the GNP growth data with separate values for two subsamples.
*
set dummy1 = t<=1973:4
set dummy2 = t>1973:4
*
linreg dlogrgnp
# dummy1 dummy2
set gnpadjust = %resids
prj removed
*
* The unemployment rate is detrended
*
filter(remove=trend) lhmur / uradjust
*
*****************************************
compute [vect[strings]] shocklabels=||"Supply","Demand"||
compute [vect[strings]] varlabels=||"Output","Unemployment"||
*
system(model=varmodel)
var gnpadjust uradjust
lags 1 to 8
det constant
end(system)
*
estimate(noprint)
@BQDoDraws(model=varmodel)
@MCGraphIRF(model=varmodel,shocklabels=shocklabels,varlabels=varlabels)
*
disp "Table 2-Variance Decomposition. Output growth break; Unemployment Detrended"
source mcfevdtable.src

@MCFEVDTable(model=varmodel,horizons=||1,2,3,4,8,12,40||,$
  varlabels=varlabels,shocklabels=shocklabels,table=byshocks)
*
**************************
system(model=varmodel)
var dlogrgnp uradjust
lags 1 to 8
det constant
end(system)
*
estimate(noprint)
@BQDoDraws(model=varmodel)
*
disp "Table 2A-Variance Decomposition. No dummy break; Unemployment Detrended"
@MCFEVDTable(model=varmodel,horizons=||1,2,3,4,8,12,40||,$
  varlabels=varlabels,shocklabels=shocklabels,table=byshocks)
**************************
system(model=varmodel)
var gnpadjust lhmur
lags 1 to 8
det constant
end(system)
*
estimate(noprint)
@BQDoDraws(model=varmodel)
disp "Table 2B-Variance Decomposition. Dummy break in GNP; No Trend in Unemployment"
@MCFEVDTable(model=varmodel,horizons=||1,2,3,4,8,12,40||,$
  varlabels=varlabels,shocklabels=shocklabels,table=byshocks)
**************************
system(model=varmodel)
var dlogrgnp lhmur
lags 1 to 8
det constant
end(system)
*
estimate(noprint)
@BQDoDraws(model=varmodel)
disp "Table 2C-Variance Decomposition. No dummy break; No Trend in Unemployment"
@MCFEVDTable(model=varmodel,horizons=||1,2,3,4,8,12,40||,$
  varlabels=varlabels,shocklabels=shocklabels,table=byshocks)

